@@ -3,7 +3,7 @@ package Labyrinth::Plugin::Users;
 use warnings;
 use strict;
 
-my $VERSION = '5.11';
+my $VERSION = '5.12';
 
 =head1 NAME
 
@@ -464,8 +464,8 @@ sub AdminSave {
         )   if($cgiparams{image});
 
     # in case of a new user
-    $tvars{data}->{'accessid'} = $tvars{data}->{'accessid'} || 1;
-    $tvars{data}->{'search'}   = $tvars{data}->{'search'} ? 1 : 0;
+    $tvars{data}->{'accessid'} = $tvars{data}->{'accessid'} ? 1 : 0;
+    $tvars{data}->{'search'}   = $tvars{data}->{'search'}   ? 1 : 0;
     $tvars{data}->{'realm'}    = Authorised(ADMIN) && $tvars{data}->{'realmid'} ? RealmName($tvars{data}->{realmid}) : $realm;
 
     my @fields = (  $tvars{data}{'accessid'}, $tvars{data}{'search'},
